@@ -9,6 +9,10 @@ from telegram_util import compactText, matchKey
 import tweepy
 import json
 import html
+import pkg_resources
+
+allowlist = pkg_resources.resource_string(__name__, 'allowlist')
+allowlist = set([str(item, 'utf-8') for item in allowlist.split() if item])
 
 with open('CREDENTIALS') as f:
 	CREDENTIALS = yaml.load(f, Loader=yaml.FullLoader)
@@ -28,10 +32,10 @@ def getCap(status):
 		for pos in range(x['indices'][0], x['indices'][1]):
 			text[pos] = ''
 	text = html.unescape(''.join(text))
-	# May need to revisit
 	for x in status.entities.get('urls', []):
 		if len(x['expanded_url']) < 30:
-			text = text.replace(x['url'], x['expanded_url'])
+			text = text.replace(x['url'], ' ' + x['expanded_url'])
+			text = text.replace('  ' + x['expanded_url'], ' ' + x['expanded_url'])
 		else:
 			text = text.replace(x['url'], '[%s](%s)' % ('link', x['expanded_url']))
 	text = compactText(html.unescape(text))
@@ -62,23 +66,32 @@ def getVideo(status):
 	return variants[-1][1]['url']
 
 def getQuote(status, func):
+	result = func(status)
 	try:
-		status.quoted_status
-		return func(status.quoted_status)
-	except:
-		...
-	try:
-		status.retweeted_status
-		return func(status.retweeted_status)
+		result = result or func(status.quoted_status)
 	except:
 		...
 
-def get(path):
+	try:
+		result = result or func(status.retweeted_status)
+	except:
+		...
+
+	try:
+		result = result or func(status.retweeted_status.quoted_status)
+	except:
+		...
+
+	return result
+
+def get(path, origin = []):
 	tid = getTid(path)
 	status = twitterApi.get_status(tid, tweet_mode="extended")
 	r = Result()
-	r.video = getVideo(status) or getQuote(status, getVideo) or ''
-	r.imgs = getImgs(status) or getQuote(status, getImgs) or []
+	if getattr(status, 'possibly_sensitive', False) and not (set(origin) & allowlist):
+		return r
+	r.video = getQuote(status, getVideo) or ''
+	r.imgs = getQuote(status, getImgs) or []
 	r.cap = getCap(status)
 	if r.cap.startswith('RT '):
 		try:
